package renderer;

import java.util.ArrayList;

import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL20;
import org.lwjgl.opengl.GL30;
import org.lwjgl.util.vector.Matrix4f;

import assets.AxisVector;
import models.Model;
import shaderPrograms.Shader;
import utilities.Utils;

public class AxisVectorRenderer {
	private Shader shader;
	
    public AxisVectorRenderer(Shader shader, Matrix4f projectionMatrix) {
        this.shader = shader;
        shader.start();
        shader.loadProjectionMatrix(projectionMatrix);
        shader.stop();
        
    }
    
    public void render(ArrayList<AxisVector> avs) {
    	
      	for (AxisVector av : avs) {
    		prepareUnitVector(av);
            loadModelMatrix(av);
            GL11.glPointSize(1);
            GL11.glDrawElements(GL11.GL_TRIANGLES, av.getModel().getVertexCount(),
                    GL11.GL_UNSIGNED_INT, 0);
            GL20.glDisableVertexAttribArray(0);
            GL20.glDisableVertexAttribArray(1);
            GL30.glBindVertexArray(0);
    	}
    
    }
 
    private void prepareUnitVector(AxisVector av) {
        Model model = av.getModel();
        GL30.glBindVertexArray(model.getVaoID());
        GL20.glEnableVertexAttribArray(0);
        GL20.glEnableVertexAttribArray(1);
    }
    
    private void loadModelMatrix(AxisVector av) {
    	Matrix4f modelMatrix = Utils.createModelMatrix(
                av.setOrigin(), (float)( av.getRotX()*180.0/(Math.PI)), (float)(av.getRotY()*180.0/(Math.PI)),(float) (av.getRotZ()*180.0/(Math.PI)), 1);
        shader.loadModelMatrix(modelMatrix);
    }
}
