package renderer;

import java.util.ArrayList;
import java.util.List;

import org.lwjgl.opengl.Display;
import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL13;
import org.lwjgl.opengl.GL20;
import org.lwjgl.opengl.GL30;
import org.lwjgl.opengl.GL32;
import org.lwjgl.util.vector.Matrix4f;
import org.lwjgl.util.vector.Vector4f;

import assets.Grid;
import assets.ViewControl;
import assets.Point;
import assets.AxisVector;
import datasets.Dataset;
import models.Model;
import renderer.Loader;
import shaderPrograms.Shader;
import utilities.Utils;



public class MainRenderer {

	public static final float FOV = 90;
    public static final float Z_NEAR = 0.5f;	
    public static final float Z_FAR = 1000f;
    
    private static final float RED = 0.8f;
    private static final float GREEN = 0.9f;
    private static final float BLUE = 1f;
    
    private Shader shader;
    private GridRenderer cubeRenderer;
    private Grid ac;
    private PointRenderer pointRenderer;
    private AxisVectorRenderer axesRenderer;
    
    public MainRenderer(Loader loader) {
	    Matrix4f projectionMatrix = Utils.createProjectionMatrix(FOV, Z_NEAR, Z_FAR, Display.getWidth(), Display.getHeight());
	    enableCulling();
	    
	    shader = new Shader();
        cubeRenderer = new GridRenderer(shader,projectionMatrix);
        pointRenderer = new PointRenderer(shader, projectionMatrix);
        axesRenderer = new AxisVectorRenderer(shader, projectionMatrix);
    }
	
    public void prepare() {
        GL11.glEnable(GL11.GL_DEPTH_TEST | GL11.GL_BLEND);
        GL11.glDepthFunc(GL11.GL_LESS);
        GL11.glBlendFunc(GL11.GL_SRC_ALPHA, GL11.GL_ONE_MINUS_SRC_ALPHA);
        GL11.glClear(GL11.GL_COLOR_BUFFER_BIT | GL11.GL_DEPTH_BUFFER_BIT);
        GL11.glClearColor(RED, GREEN, BLUE, 1);
    }
    
    public void cleanUp() {
    	shader.cleanUp();
    }
    
    public static void enableCulling() {
    	GL11.glEnable(GL11.GL_CULL_FACE);
        GL11.glCullFace(GL11.GL_BACK);
    }
    
    public static void disableCulling() {
    	GL11.glDisable(GL11.GL_CULL_FACE);
    }
    
 
    
    public void render(Grid ac, Dataset points, ViewControl camera) {
    	prepare();
        
    	shader.start();
    	shader.loadViewMatrix(camera);
    	
        cubeRenderer.render(ac);
        pointRenderer.render(points.getPoints());
        disableCulling();
        axesRenderer.render(points.getManipAvs());
        enableCulling();
        
        shader.stop();
    }
}
