package renderer;

import java.util.ArrayList;

import org.lwjgl.opengl.GL11;
import org.lwjgl.opengl.GL20;
import org.lwjgl.opengl.GL30;
import org.lwjgl.util.vector.Matrix4f;
import org.lwjgl.util.vector.Vector3f;

import assets.Point;
import models.Model;
import shaderPrograms.Shader;
import utilities.Utils;

public class PointRenderer {

	private Shader shader;
	 
    public PointRenderer(Shader shader, Matrix4f projectionMatrix) {
        this.shader = shader;
        shader.start();
        shader.loadProjectionMatrix(projectionMatrix);
        shader.stop();
        
    }
    
    public void render(ArrayList<Point> points) {
  
    	for (Point p : points) {
            preparePoint(p);
            loadModelMatrix(p);
            GL11.glPointSize(4);
            GL11.glDrawElements(GL11.GL_POINTS, p.getModel().getVertexCount(),
                    GL11.GL_UNSIGNED_INT, 0);
            GL20.glDisableVertexAttribArray(0);
            GL20.glDisableVertexAttribArray(1);
            GL30.glBindVertexArray(0);
    	}
    }
 
    private void preparePoint(Point point) {
        Model model = point.getModel();
        GL30.glBindVertexArray(model.getVaoID());
        GL20.glEnableVertexAttribArray(0);
        GL20.glEnableVertexAttribArray(1);
    }
    
    private void loadModelMatrix(Point point) {
        Matrix4f modelMatrix = Utils.createModelMatrix(
                new Vector3f(0, 0, 0), 0, 0, 0, 0.5f);
        shader.loadModelMatrix(modelMatrix);
    }
}
